/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.apps.component.cfw;

import java.io.File;
import java.net.URI;
import java.net.URISyntaxException;
import java.util.ArrayList;
import java.util.List;
import java.util.Iterator;
import java.util.Enumeration;

import java.awt.*;
import java.awt.event.*;

import javax.swing.*;
import javax.swing.table.*;
import javax.swing.border.TitledBorder;
import javax.swing.event.ListSelectionListener;
import javax.swing.event.ListSelectionEvent;

import gov.sns.application.*;

// jwizz wizard toolkit
import net.javaprog.ui.wizard.*;

// persistence layer
import gov.anl.aps.irmis.persistence.pv.IOCBoot;
import gov.anl.aps.irmis.persistence.pv.IOCResource;
import gov.anl.aps.irmis.persistence.pv.Record;
import gov.anl.aps.irmis.persistence.pv.Field;

// service layer

// wizards
import gov.anl.aps.irmis.apps.component.cfw.wizard.*;

/**
 * Primary GUI for IRMIS Component Viewer application. All window layout, and Swing event
 * listeners are done here. Business logic work is delegated to <code>ComponentDocument</code>,
 * which in turn requests that the ComponentModel notify us here of changes to the data. In short,
 * we listen for <code>ComponentModelEvent</code> here.
 */
public class ComponentWindow extends XalInternalWindow {

	/** The main model for the document */
	final protected ComponentModel _model;

	// Swing GUI components
    private JPanel topPanel;
	
	/** 
	 * Creates a new instance of ComponentWindow
	 * @param aDocument The document for this window
	 */
    public ComponentWindow(final XalInternalDocument aDocument) {
        super(aDocument);

		_model = ((ComponentDocument)aDocument).getModel();

        // make ComponentWindow a listener for changes in ComponentModel
		_model.addComponentModelListener( new ComponentModelListener() {
                public void modified(ComponentModelEvent e) {
                    updateView(e);
                }
            });

        // initial application window size
        setSize(300, 80);

        // build contents
		makeContents();
    }

    /**
     * Top-level method to build up Swing GUI components.
     */
    public void makeContents() {

        // topmost organization 
        topPanel = new JPanel();
        JButton addNewCompTypeButton = new JButton("Add Component Type...");
        addNewCompTypeButton.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent e) {
                    showAddNewCompTypeWizard();
                }
            });        
        
        topPanel.add(addNewCompTypeButton);

    	getContentPane().add(topPanel);
    }

    private void showAddNewCompTypeWizard() {
        DataModel dataModel = new DataModel();
        WizardModel wizardModel = new DefaultWizardModel(new Step[] {
            new ComponentTypeWelcomeStep(),
            new ComponentTypeFinishStep()
        });
        
        wizardModel.addWizardModelListener(new WizardModelListener() {
                public void wizardFinished(WizardModelEvent e) {
                    System.out.println("** wizard finished ");
                }
                public void wizardCanceled(WizardModelEvent e) {
                    System.out.println("** wizard cancelled ");
                }
                public void stepShown(WizardModelEvent e) {
                    System.out.println("** wizard step shown ");
                }
                public void wizardModelChanged(WizardModelEvent e) {
                    System.out.println("** wizard data model changed ");
                }
            });
        
        Wizard wizard = new Wizard(wizardModel, "Component Type Wizard");
        wizard.pack();
        wizard.setLocationRelativeTo(null);
        wizard.setVisible(true);
    }


    /**
     * Update graphical view of PVModel data based on event type.
     *
     * @param event type of data model change
     */
    public void updateView(ComponentModelEvent event) {

    }

    /********************************************************************
     * Inner classes supporting Swing components
     ********************************************************************/

}
