/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.apps.ioc.cfw;

import gov.anl.aps.irmis.persistence.pv.IOCAttribute;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;


public class IOCAttributeEditDialog extends JDialog
                        implements ActionListener {
    private static IOCAttributeEditDialog dialog;
    private static IOCAttribute iocAttr = null;
    JTextField iocAttrNameTextField;
    JTextField iocAttrValueTextField;

    /**
     * Puts up a ioc edit dialog box, returning a possibly modified IOC object.
     *
     * @param frameComp component within whose frame this dialog will be rendered
     * @param locationComp component that login dialog should show up near (can be null)
     * @param ioc ioc object that is the subject of editing
     * @return possibly modified IOC object
     */
    public static IOCAttribute showDialog(Component frameComp,
                                 Component locationComp, IOCAttribute iocAttribute,
                                 boolean newIocAttribute) {
        Frame frame = JOptionPane.getFrameForComponent(frameComp);
        String dialogTitle = null;
        if (newIocAttribute) {
            IOCAttributeEditDialog.iocAttr = new IOCAttribute();
            dialogTitle = "Add New IOC Attribute Dialog";
        } else {
            IOCAttributeEditDialog.iocAttr = iocAttribute;
            dialogTitle = "Edit IOC Attribute Dialog";
        }
        
        dialog = new IOCAttributeEditDialog(frame, locationComp, dialogTitle);
        dialog.setVisible(true);
        return IOCAttributeEditDialog.iocAttr;
    }

    private IOCAttributeEditDialog(Frame frame,
                        Component locationComp, String title) {
        super(frame, title, true);

        //Create and initialize the buttons.
        JButton cancelButton = new JButton("Cancel");
        cancelButton.setActionCommand("Cancel");
        cancelButton.addActionListener(this);
        //
        final JButton saveButton = new JButton("Save");
        saveButton.setActionCommand("Save");
        saveButton.addActionListener(this);
        getRootPane().setDefaultButton(saveButton);

        //main part of the dialog

        // attribute name text field
        IOCAttribute iocAttr = IOCAttributeEditDialog.iocAttr;
        if (iocAttr.getAttributeType() == null)
            System.out.println("************ iocAttr.getAttributeType() is null ****************");
        iocAttrNameTextField = new JTextField();
        iocAttrNameTextField.setText(iocAttr.getAttributeType().getAttributeType());

        // attribute value text field
        iocAttrValueTextField = new JTextField();
        iocAttrValueTextField.setText(iocAttr.getAttributeValue());

        JPanel textInputPane = new JPanel();
        textInputPane.setLayout(new BoxLayout(textInputPane, BoxLayout.PAGE_AXIS));
        JLabel uLabel = new JLabel("Attribute Name:",SwingConstants.LEFT);
        textInputPane.add(uLabel);
        textInputPane.add(iocAttrNameTextField);
        JLabel aLabel = new JLabel("Attribute Value:",SwingConstants.LEFT);
        textInputPane.add(aLabel);
        textInputPane.add(iocAttrValueTextField);
        textInputPane.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));

        //Lay out the buttons from left to right.
        JPanel buttonPane = new JPanel();
        buttonPane.setLayout(new BoxLayout(buttonPane, BoxLayout.LINE_AXIS));
        buttonPane.setBorder(BorderFactory.createEmptyBorder(0, 10, 10, 10));
        buttonPane.add(Box.createHorizontalGlue());
        buttonPane.add(cancelButton);
        buttonPane.add(Box.createRigidArea(new Dimension(10, 0)));
        buttonPane.add(saveButton);

        //Put everything together, using the content pane's BorderLayout.
        Container contentPane = getContentPane();
        contentPane.add(textInputPane, BorderLayout.CENTER);
        contentPane.add(buttonPane, BorderLayout.PAGE_END);

        //Initialize values.
        pack();
        setLocationRelativeTo(locationComp);
    }

    //Handle clicks on the Set and Cancel buttons.
    public void actionPerformed(ActionEvent e) {
        if ("Save".equals(e.getActionCommand())) {
            // copy widget data to IOCAttributeEditDialog.iocAttr object
            IOCAttribute iocAttr = IOCAttributeEditDialog.iocAttr;
            /*
            ioc.setIocName(iocNameTextField.getText());
            String choice = (String)activeComboBox.getSelectedItem();
            if (choice.equals("Active"))
                ioc.setActive(true);
            else
                ioc.setActive(false);
            */

        } else if ("Cancel".equals(e.getActionCommand())) {
            // ditch any new IOCAttribute that may have been created
            IOCAttributeEditDialog.iocAttr = null;
        }
        IOCAttributeEditDialog.dialog.setVisible(false);
    }
}
