/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.apps.ioc.cfw;

import java.util.List;
import java.util.ArrayList;
import java.util.Iterator;

import gov.anl.aps.irmis.persistence.pv.IOC;
import gov.anl.aps.irmis.persistence.pv.IOCAttribute;

/**
 * Application data model for IRMIS IOC app. Stores graph of current set of ioc's
 * and related data. 
 * A list of listeners interested in this data is maintained, and
 * notified as requested.
 */
public class IOCModel {

    // list of others interested in changes to the data model
    private List iocModelListenersList = new ArrayList();

    // list of IOC records in irmis db
    private List iocList;

    // ioc chosen from above list
    private IOC selectedIoc;

    // ioc attribute chosen from selected ioc
    private IOCAttribute selectedIocAttr;

    // list of possible ioc attribute types (ie. possible names)
    private List iocAttrTypeList;

	/**
	 * Do nothing constructor
	 */
	public IOCModel() {
	}

    public void addIOCModelListener(IOCModelListener l) {
        iocModelListenersList.add(l);
    }

    public void notifyIOCModelListeners() {
        notifyIOCModelListeners(null);
    }

    /**
     * Notify registered listeners of the given <code>IOCModelEvent</code>.
     *
     * @param modelEvent encapsulates one of several possible events
     */
    public void notifyIOCModelListeners(IOCModelEvent modelEvent) {
        Iterator it = iocModelListenersList.iterator();
        while (it.hasNext()) {
            IOCModelListener l = (IOCModelListener)it.next();
            l.modified(modelEvent);
        }
    }

    public List getIocList() {
        return iocList;
    }
    public void setIocList(List iocList) {
        this.iocList = iocList;
    }

    public List getIocAttributeTypeList() {
        return iocAttrTypeList;
    }
    public void setIocAttributeTypeList(List iocAttrTypeList) {
        this.iocAttrTypeList = iocAttrTypeList;
    }

    public IOC getSelectedIoc() {
        return selectedIoc;
    }
    public void setSelectedIoc(IOC value) {
        selectedIoc = value;
    }

    public IOCAttribute getSelectedIocAttribute() {
        return selectedIocAttr;
    }
    public void setSelectedIocAttribute(IOCAttribute value) {
        selectedIocAttr = value;
    }

}
