/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.persistence.component;

import gov.anl.aps.irmis.persistence.IRMISDataObject;
import gov.anl.aps.irmis.persistence.HashCodeUtil;

import java.util.Date;
import java.util.Set;
import java.util.HashSet;

/**
 * IRMIS business object that represents 
 * This class is mapped via hibernate one-to-one with IRMIS component_port_template table.
 */
public class ComponentPortTemplate extends IRMISDataObject {

    private ComponentType componentType;
    private ComponentPortType componentPortType;
    private Set portPinTemplates = new HashSet();

    private String componentPortName;
    private int componentPortOrder;
    private boolean virtual;
    private Date modifiedDate;
    private String modifiedBy;

    /**
     * Do-nothing constructor.
     */
    public ComponentPortTemplate() {
    }

    /**
     * 
     */
    public ComponentType getComponentType() {
        return this.componentType;
    }
    /**
     * 
     */
    public void setComponentType(ComponentType value) {
        this.componentType = value;
    }

    /**
     * 
     */
    public ComponentPortType getComponentPortType() {
        return this.componentPortType;
    }
    /**
     * 
     */
    public void setComponentPortType(ComponentPortType value) {
        this.componentPortType = value;
    }

    /**
     * 
     */
    public Set getPortPinTemplates() {
        return this.portPinTemplates;
    }
    /**
     * 
     */
    public void setPortPinTemplates(Set value) {
        this.portPinTemplates = value;
    }
    /**
     * Add one PortPinTemplate to set. Establishes bidirectional
     * identity.
     */
    public void addPortPinTemplate(PortPinTemplate template) {
        template.setComponentPortTemplate(this);
        portPinTemplates.add(template);
    }

    /**
     * 
     */
    public String getComponentPortName() {
        return this.componentPortName;
    }
    /**
     * 
     */
    public void setComponentPortName(String value) {
        this.componentPortName = value;
    }

    /**
     * 
     */
    public int getComponentPortOrder() {
        return this.componentPortOrder;
    }
    /**
     * 
     */
    public void setComponentPortOrder(int value) {
        this.componentPortOrder = value;
    }


    /**
     * 
     */
    public boolean getVirtual() {
        return this.virtual;
    }
    public void setVirtual(boolean value) {
        this.virtual = value;
    }


    /**
     * Direct reflection of last modification of underlying database row.
     */
    public Date getModifiedDate() {
        return this.modifiedDate;
    }
    public void setModifiedDate(Date value) {
        this.modifiedDate = value;
    }

    /**
     * Represent user name or application name which last modified (created)
     * underlying database row.
     */
    public String getModifiedBy() {
        return this.modifiedBy;
    }
    public void setModifiedBy(String value) {
        this.modifiedBy = value;
    }


    public String toString() {
        return getId().toString();
    }

    /**
     * Custom equals which compares "business key" equality.
     */
    public boolean equals(Object other) {
        if (this==other) return true;
        if ( !(other instanceof ComponentPortTemplate) ) return false;
        final ComponentPortTemplate castOther = (ComponentPortTemplate)other;
        return this.getComponentType().getId() == castOther.getComponentType().getId() &&
            this.getComponentPortOrder() == castOther.getComponentPortOrder();
    }

    /**
     * Custom hashCode computed on "business key" fields.
     */
    public int hashCode() {
        int result = HashCodeUtil.SEED;
        result = HashCodeUtil.hash(result, getComponentType().getId());
        result = HashCodeUtil.hash(result, getComponentPortOrder());
        return result;
    }

}
