/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.persistence.component;

import gov.anl.aps.irmis.persistence.IRMISDataObject;
import gov.anl.aps.irmis.persistence.HashCodeUtil;

import java.util.Date;
import java.util.Set;
import java.util.HashSet;

/**
 * IRMIS business object that represents 
 * This class is mapped via hibernate one-to-one with IRMIS component_port_type table.
 */
public class ComponentPortType extends IRMISDataObject {

    private String componentPortType;
    private String componentPortGroup;
    private int componentPortPinCount;
    private Set portPinDesignators = new HashSet();
    private Date modifiedDate;
    private String modifiedBy;

    /**
     * Do-nothing constructor.
     */
    public ComponentPortType() {
    }

    /**
     * 
     */
    public String getComponentPortType() {
        return this.componentPortType;
    }
    /**
     * 
     */
    public void setComponentPortType(String value) {
        this.componentPortType = value;
    }

    /**
     * 
     */
    public String getComponentPortGroup() {
        return this.componentPortGroup;
    }
    /**
     * 
     */
    public void setComponentPortGroup(String value) {
        this.componentPortGroup = value;
    }

    /**
     * 
     */
    public int getComponentPortPinCount() {
        return this.componentPortPinCount;
    }
    /**
     * 
     */
    public void setComponentPortPinCount(int value) {
        this.componentPortPinCount = value;
    }

    /**
     * 
     */
    public Set getPortPinDesignators() {
        return this.portPinDesignators;
    }
    /**
     * 
     */
    public void setPortPinDesignators(Set value) {
        this.portPinDesignators = value;
    }
    /**
     * Add one PortPinDesignator to set. Establishes bidirectional
     * identity.
     */
    public void addPortPinDesignator(PortPinDesignator ppd) {
        ppd.setComponentPortType(this);
        portPinDesignators.add(ppd);
    }


    /**
     * Direct reflection of last modification of underlying database row.
     */
    public Date getModifiedDate() {
        return this.modifiedDate;
    }
    public void setModifiedDate(Date value) {
        this.modifiedDate = value;
    }

    /**
     * Represent user name or application name which last modified (created)
     * underlying database row.
     */
    public String getModifiedBy() {
        return this.modifiedBy;
    }
    public void setModifiedBy(String value) {
        this.modifiedBy = value;
    }


    public String toString() {
        return getId().toString();
    }

    /**
     * Custom equals which compares "business key" equality.
     */
    public boolean equals(Object other) {
        if (this==other) return true;
        if ( !(other instanceof ComponentPortType) ) return false;
        final ComponentPortType castOther = (ComponentPortType) other;
        return this.getComponentPortType().equals(castOther.getComponentPortType());
    }

    /**
     * Custom hashCode computed on "business key" fields.
     */
    public int hashCode() {
        int result = HashCodeUtil.SEED;
        result = HashCodeUtil.hash(result, getComponentPortType());
        return result;
    }

}
