/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.persistence.component;

import net.sf.hibernate.type.Type;
import net.sf.hibernate.Hibernate;

import gov.anl.aps.irmis.persistence.BaseDAO;
import gov.anl.aps.irmis.persistence.DAOException;

import java.util.List;

/**
 * Methods for finding/saving IRMIS <code>ComponentPortType</code>.
 */
public class ComponentPortTypeDAO extends BaseDAO {

    /**
     * Do nothing constructor.
     */
    public ComponentPortTypeDAO() throws DAOException {
        super();
    }

    /**
     * Find set of all component port types.
     * 
     * @return list of <code>ComponentPortType</code> objects
     * @throws DAOException
     */
    public List findAllComponentPortTypes() throws DAOException {
        return retrieveObjs("from ComponentPortType cpt",null,null);
    }

    /**
     * Find a particular component port type by name.
     *
     * @param typeName string port type name
     * @return single object instance
     */
    public ComponentPortType findComponentPortType(String componentPortTypeName) 
        throws DAOException {
        String query = "from ComponentPortType cpt where cpt.componentPortType = ?";
        String[]values = {componentPortTypeName};
        Type[]types = {Hibernate.STRING};

        return (ComponentPortType)retrieveObj(query, values, types);
                        
    }

    /**
     * Save a new instance of ComponentPortType.
     */
    public void save(ComponentPortType componentPortType) throws DAOException {
        storeObj(componentPortType);
    }

}
