/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.persistence.component;

import gov.anl.aps.irmis.persistence.IRMISDataObject;
import gov.anl.aps.irmis.persistence.HashCodeUtil;

import java.util.Date;
import java.util.Set;
import java.util.HashSet;

/**
 * IRMIS business object that represents 
 * This class is mapped via hibernate one-to-one with IRMIS component_type table.
 */
public class ComponentType extends IRMISDataObject {

    private FormFactor formFactor;
    private Manufacturer manufacturer;

    private Set componentPortTemplates = new HashSet();
    private Set componentTypeFunctions = new HashSet();
    private Set componentTypeInterfaces = new HashSet();
    private Set componentTypeCognitivePersons = new HashSet();
    private Set componentTypeDocuments = new HashSet();
    private Set componentTypeStatus = new HashSet();

    private String componentTypeName;
    private String description;
    private Date modifiedDate;
    private String modifiedBy;

    /**
     * Do-nothing constructor.
     */
    public ComponentType() {
    }

    /**
     * 
     */
    public FormFactor getFormFactor() {
        return this.formFactor;
    }
    /**
     * 
     */
    public void setFormFactor(FormFactor value) {
        this.formFactor = value;
    }

    /**
     * 
     */
    public Manufacturer getManufacturer() {
        return this.manufacturer;
    }
    /**
     * 
     */
    public void setManufacturer(Manufacturer value) {
        this.manufacturer = value;
    }

    /**
     * 
     */
    public Set getComponentPortTemplates() {
        return this.componentPortTemplates;
    }
    /**
     * 
     */
    public void setComponentPortTemplates(Set value) {
        this.componentPortTemplates = value;
    }
    /**
     * Add one ComponentPortTemplate to set. Establishes bidirectional
     * identity.
     */
    public void addComponentPortTemplate(ComponentPortTemplate template) {
        template.setComponentType(this);
        componentPortTemplates.add(template);
    }

    /**
     * 
     */
    public Set getComponentTypeFunctions() {
        return this.componentTypeFunctions;
    }
    /**
     * 
     */
    public void setComponentTypeFunctions(Set value) {
        this.componentTypeFunctions = value;
    }
    /**
     * Add one ComponentTypeFunction to set. Establishes bidirectional
     * identity.
     */
    public void addComponentTypeFunction(ComponentTypeFunction ctf) {
        ctf.setComponentType(this);
        componentTypeFunctions.add(ctf);
    }

    /**
     * 
     */
    public Set getComponentTypeInterfaces() {
        return this.componentTypeInterfaces;
    }
    /**
     * 
     */
    public void setComponentTypeInterfaces(Set value) {
        this.componentTypeInterfaces = value;
    }
    /**
     * Add one ComponentTypeInterface to set. Establishes bidirectional
     * identity.
     */
    public void addComponentTypeInterface(ComponentTypeInterface cti) {
        cti.setComponentType(this);
        componentTypeInterfaces.add(cti);
    }

    /**
     * 
     */
    public Set getComponentTypeCognitivePersons() {
        return this.componentTypeCognitivePersons;
    }
    /**
     * 
     */
    public void setComponentTypeCognitivePersons(Set value) {
        this.componentTypeCognitivePersons = value;
    }
    /**
     * Add one ComponentTypeCognitivePerson to set. Establishes bidirectional
     * identity.
     */
    public void addComponentTypeCognitivePerson(ComponentTypeCognitivePerson ctcp) {
        ctcp.setComponentType(this);
        componentTypeCognitivePersons.add(ctcp);
    }

    /**
     * 
     */
    public Set getComponentTypeDocuments() {
        return this.componentTypeDocuments;
    }
    /**
     * 
     */
    public void setComponentTypeDocuments(Set value) {
        this.componentTypeDocuments = value;
    }
    /**
     * Add one ComponentTypeDocument to set. Establishes bidirectional
     * identity.
     */
    public void addComponentTypeDocument(ComponentTypeDocument ctd) {
        ctd.setComponentType(this);
        componentTypeDocuments.add(ctd);
    }

    /**
     * 
     */
    public Set getComponentTypeStatus() {
        return this.componentTypeStatus;
    }
    /**
     * 
     */
    public void setComponentTypeStatus(Set value) {
        this.componentTypeStatus = value;
    }
    /**
     * Add one ComponentTypeStatus to set. Establishes bidirectional
     * identity.
     */
    public void addComponentTypeStatus(ComponentTypeStatus cts) {
        cts.setComponentType(this);
        componentTypeStatus.add(cts);
    }


    /**
     * 
     */
    public String getComponentTypeName() {
        return this.componentTypeName;
    }
    /**
     * 
     */
    public void setComponentTypeName(String value) {
        this.componentTypeName = value;
    }

    /**
     * 
     */
    public String getDescription() {
        return this.description;
    }
    /**
     * 
     */
    public void setDescription(String value) {
        this.description = value;
    }


    /**
     * Direct reflection of last modification of underlying database row.
     */
    public Date getModifiedDate() {
        return this.modifiedDate;
    }
    public void setModifiedDate(Date value) {
        this.modifiedDate = value;
    }

    /**
     * Represent user name or application name which last modified (created)
     * underlying database row.
     */
    public String getModifiedBy() {
        return this.modifiedBy;
    }
    public void setModifiedBy(String value) {
        this.modifiedBy = value;
    }


    public String toString() {
        return getId().toString();
    }

    /**
     * Custom equals which compares "business key" equality.
     */
    public boolean equals(Object other) {
        if (this==other) return true;
        if ( !(other instanceof ComponentType) ) return false;
        final ComponentType castOther = (ComponentType)other;
        return this.getComponentTypeName().equals(castOther.getComponentTypeName());
    }

    /**
     * Custom hashCode computed on "business key" fields.
     */
    public int hashCode() {
        int result = HashCodeUtil.SEED;
        result = HashCodeUtil.hash(result, getComponentTypeName());
        return result;
    }

}
