/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.persistence.component;

import net.sf.hibernate.type.Type;
import net.sf.hibernate.Hibernate;

import gov.anl.aps.irmis.persistence.BaseDAO;
import gov.anl.aps.irmis.persistence.DAOException;

import java.util.List;

/**
 * Methods for finding/saving IRMIS <code>ComponentType</code>.
 */
public class ComponentTypeDAO extends BaseDAO {

    /**
     * Do nothing constructor.
     */
    public ComponentTypeDAO() throws DAOException {
        super();
    }

    /**
     * Find set of all component types.
     * 
     * @return list of <code>ComponentType</code> objects
     * @throws DAOException
     */
    public List findAllComponentTypes() throws DAOException {
        return retrieveObjs("from ComponentType ct",null,null);
    }

    /**
     * Find a particular component type by name.
     *
     * @param typeName string component type name
     * @return single object instance
     */
    public ComponentType findComponentType(String typeName) throws DAOException {
        String query = "from ComponentType ct where ct.componentTypeName = ?";
        String[]values = {typeName};
        Type[]types = {Hibernate.STRING};

        return (ComponentType)retrieveObj(query, values, types);
    }

    public void save(ComponentType compType) throws DAOException {
        storeObj(compType);
    }

}
