/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.persistence.component;

import net.sf.hibernate.type.Type;
import net.sf.hibernate.Hibernate;

import gov.anl.aps.irmis.persistence.BaseDAO;
import gov.anl.aps.irmis.persistence.DAOException;

import java.util.List;

/**
 * Methods for finding/saving IRMIS <code>ComponentTypeInterfaceType</code>.
 */
public class ComponentTypeInterfaceTypeDAO extends BaseDAO {

    /**
     * Do nothing constructor.
     */
    public ComponentTypeInterfaceTypeDAO() throws DAOException {
        super();
    }

    /**
     * Find set of all component types interface types.
     * 
     * @return list of <code>ComponentTypeInterfaceType</code> objects
     * @throws DAOException
     */
    public List findAllInterfaceTypes() throws DAOException {
        return retrieveObjs("from ComponentTypeInterfaceType ctit",null,null);
    }

    /**
     * Find a particular component type interface type by name.
     *
     * @param typeName string interface type name
     * @return single object instance
     */
    public ComponentTypeInterfaceType findInterfaceType(String typeName) 
        throws DAOException {
        String query = "from ComponentTypeInterfaceType ctit where ctit.interfaceType = ?";
        String[]values = {typeName};
        Type[]types = {Hibernate.STRING};

        return (ComponentTypeInterfaceType)retrieveObj(query, values, types);
                        
    }

    /**
     * Save a new instance of ComponentTypeInterfaceType.
     */
    public void save(ComponentTypeInterfaceType compTypeIntType) throws DAOException {
        storeObj(compTypeIntType);
    }

}
