/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.persistence.login;

import gov.anl.aps.irmis.persistence.BaseDAO;
import gov.anl.aps.irmis.persistence.DAOException;

import net.sf.hibernate.type.Type;
import net.sf.hibernate.Hibernate;

import java.util.List;

/**
 * Method for explicitly finding a person by userid and instantiating
 * a <code>Person</code> object.
 */
public class PersonDAO extends BaseDAO {

    /**
     * Do nothing constructor.
     */
    public PersonDAO() throws DAOException {
        super();
    }

    /**
     * Find a particular Person by userid.
     * 
     * @param userid string representing (typically) the unix userid
     * @return <code>Person</code> object
     * @throws DAOException
     */
    public Person findPerson(String userid) throws DAOException {
        String query = "from Person p where p.userid = ?";
        String[]values = {userid};
        Type[]types = {Hibernate.STRING};
        return (Person)retrieveObj(query,values,types);
    }

    /**
     * Find a Person as best we can by comparing the given name with
     * the userid, first, middle, and last name.
     */
    public Person findByFreeTextName(String name) throws DAOException {
        String query = "from Person p where p.lastName = ?";
        String[]values = {name};
        Type[]types = {Hibernate.STRING};
        return (Person)retrieveObj(query,values,types);
    }

}
