/*
   Copyright (c) 2004-2005 The University of Chicago, as Operator
   of Argonne National Laboratory.
*/
package gov.anl.aps.irmis.persistence.pv;

import gov.anl.aps.irmis.persistence.IRMISDataObject;
import gov.anl.aps.irmis.persistence.HashCodeUtil;

import java.util.Date;

/**
 * IRMIS business object that represents a single IOC Attribute type.
 * This class is mapped via hibernate almost one-to-one with IRMIS ioc_attr_type table.
 */
public class IOCAttributeType extends IRMISDataObject implements Comparable {

    private String attributeName;

    /**
     * Constructor
     */
    public IOCAttributeType() {
    }

    /**
     * Get the attributes type.
     */
    public String getAttributeType() {
        return this.attributeName;
    }
    /**
     * Set the attributes type. 
     */    
    public void setAttributeType(String attributeName) {
        this.attributeName = attributeName;
    }

    public String toString() {
        return getId().toString() + ":" + getAttributeType();
    }

    /**
     * Required to implement Comparable interface. Orders attributes by the
     * attribute type name. Not generally recommended
     * that compareTo uses different comparators than equals method, but
     * should be ok with our expected usage.
     */
    public int compareTo(Object o) {
        IOCAttributeType otherAttrType = (IOCAttributeType)o;
        return this.getAttributeType()
            .compareTo(otherAttrType.getAttributeType());
    }

    /**
     * Custom equals which compares "business key" equality.
     */
    public boolean equals(Object other) {
        if (this==other) return true;
        if ( !(other instanceof IOCAttributeType) ) return false;
        final IOCAttributeType castOther = (IOCAttributeType) other;
        return this.getAttributeType().equals(castOther.getAttributeType());
    }

    /**
     * Custom hashCode computed on "business key" fields.
     */
    public int hashCode() {
        int result = HashCodeUtil.SEED;
        result = HashCodeUtil.hash(result, getAttributeType());
        return result;
    }

}
